@@ -375,8 +375,18 @@ def pytest_runtestloop(session):
 
         completed = []
         while tasks:
+
+            # Mark when the task was started
+            for task in tasks:
+                if isinstance(task, asyncio.Task):
+                    item = item_by_coro[task._coro]
+                else:
+                    item = item_by_coro[task]
+                if not hasattr(item, "enqueue_time"):
+                    item.enqueue_time = time.time()
+
             done, pending = await asyncio.wait(
-                tasks, return_when=asyncio.FIRST_COMPLETED, timeout=5
+                tasks, return_when=asyncio.FIRST_COMPLETED, timeout=30
             )
 
             # Cancel tasks that have taken too long
@@ -384,7 +394,7 @@ def pytest_runtestloop(session):
             for task in pending:
                 now = time.time()
                 item = item_by_coro[task._coro]
-                if hasattr(item, "start") and task_timeout < now - item.start:
+                if task_timeout < now - item.enqueue_time:
                     task.cancel()
                 tasks.append(task)
 
